@@ -25,10 +25,12 @@ struct appres_struct {
 
   String geometry;
   Boolean inherit_geometry;
+  Boolean version;
   Boolean debug;
   Boolean xtest;
   Boolean no_sync;
   Boolean always_on_top;
+  Boolean wm_toolbar;
   Boolean jump_pointer;
   Boolean jump_pointer_always;
   Boolean jump_pointer_back;
